<?php

namespace Drupal\Tests\nodeify\Functional;

use Drupal\Tests\node\Functional\NodeTestBase;

/**
 * Tests configuration pages for nodeify.
 *
 * @group nodeify
 */
class ConfigTest extends NodeTestBase {

  /**
   * {@inheritdoc}
   */
  public static $modules = [
    'nodeify',
    'field_ui',
    'block'
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp() {
    parent::setUp();
  }

  /**
   * Adds messages for update/delete/create and tests node save.
   */
  public function testNodeTypeEditForm() {
    $assert_session = $this->assertSession();
    $this->drupalPlaceBlock('system_breadcrumb_block');
    $permissions = ['bypass node access', 'administer content types', 'administer node fields'];
    // User without specific permissions.
    $web_user = $this->drupalCreateUser($permissions);
    $this->drupalLogin($web_user);

    $this->drupalGet('admin/structure/types/manage/page');
    $assert_session->pageTextNotContains('Message settings');

    $permissions[] = 'administer nodeify';
    // User with the correct permission.
    $web_user = $this->drupalCreateUser($permissions);
    $this->drupalLogin($web_user);
    $this->drupalGet('admin/structure/types/manage/page');
    $assert_session->pageTextContains('Message settings');

    $message_text = [
      'nodeify[create]' => 'New page created',
      'nodeify[update]' => 'Page updated',
      'nodeify[delete]' => 'Page deleted',
    ];
    $this->drupalPostForm('admin/structure/types/manage/page', $message_text, t('Save content type'));

    $edit = [
      'title[0][value]' => 'Test page',
      'body[0][value]' => 'Test body text',
    ];
    $this->drupalPostForm('node/add/page', $edit, t('Save'));

    $assert_session->statusCodeEquals(200);
    $assert_session->pageTextContains($message_text['nodeify[create]']);

    /** @var \Drupal\Node\NodeStorageInterface $node_storage */
    $node_storage = $this->container->get('entity_type.manager')->getStorage('node');
    // Verify forum.
    $nodes = $node_storage->loadByProperties([
      'type' => 'page',
      'title' => 'Test page',
    ]);
    $node = array_shift($nodes);

    $this->drupalPostForm('node/' . $node->id() . '/edit', [], t('Save'));
    $assert_session->statusCodeEquals(200);
    $assert_session->pageTextContains($message_text['nodeify[update]']);

    $this->drupalPostForm('node/' . $node->id() . '/delete', [], t('Delete'));
    $assert_session->statusCodeEquals(200);
    $assert_session->pageTextContains($message_text['nodeify[delete]']);

    return [
      'id' => $node->id(),
    ];
  }
}
